@@ -11,4 +11,13 @@ class GroupNotFound(NetModelException):
     pass
 
 class VlanNotFound(NetModelException):
+    pass
+
+class DuplicateVlans(NetModelException):
+    pass
+
+class DuplicateHosts(NetModelException):
+    pass
+
+class InvalidInterfaceName(NetModelException):
     pass
\ No newline at end of file
